Permessi per l'assistenza ai familiari disabili
Description: L’ordinamento del nostro Paese prevede una normativa di riferimento in materia di disabilità, regolarizzata dalla Legge 104 del 1992, la quale si rivolge ai soggetti che presentano “una minorazione fisica, psichica o sensoriale, stabilizzata o progressiva, che è causa di difficoltà di apprendimento, di relazione o di integrazione”. Tale legge disciplina l’integrazione sociale, i diritti delle […]
Date: 2018-12-28T06:32:33+00:00

Vai al contenuto

#### Amministrazione di sostegno: a chi spetta la tutela

#### Polizza infortuni

#### Pagine web accessibili: i benefici per i disabili

#### Arredare un bagno per disabili

#### Perché scegliere una carrozzina leggera per disabili

#### Parcheggi disabili: cosa cambia con il Nuovo Codice della Strada 2021

# Permessi per l’assistenza ai familiari disabili

L’ordinamento del nostro Paese prevede una normativa di riferimento in materia di disabilità, regolarizzata dalla Legge 104 del 1992, la quale si rivolge ai soggetti che presentano “una minorazione fisica, psichica o sensoriale, stabilizzata o progressiva, che è causa di difficoltà di apprendimento, di relazione o di integrazione”. Tale legge disciplina l’integrazione sociale, i diritti delle persone disabili e la loro assistenza, con l’obiettivo di superare gli ostacoli e aiutare i soggetti con handicap, favorendo alcuni benefici anche per le persone che se ne prendono cura.

Tra le agevolazioni, i lavoratori dipendenti (anche part time) che hanno un familiare con riconosciuta disabilità grave dall’apposita Commissione Medica, possono usufruire di permessi per l’assenza dal lavoro, quantificati in 3 giorni al mese, anche non continuativi, da dedicare particolarmente alle cure o, comunque, ad una vicinanza supplementare rispetto a quella che già vige in maniera abitudinaria.

Naturalmente, per avere diritto ai benefici della Legge 104, è necessario seguire un iter che dimostri e confermi l’esistenza dei requisiti, il quale segue 3 fondamentali passaggi:

- Riconoscimento dello stato di disabilità, tramite un certificato medico attestante l’handicap, da inoltrare all’Inps per l’accertamento
- Visita di controllo da parte di una commissione ATS, di concerto con un medico dell’Inps
- Rilascio, entro 90 giorni, di una dichiarazione attestante lo stato di handicap, che consentirà di avere l’accesso ai benefit di legge.

Al termine di questo percorso, si potrà passare alla richiesta online, tramite Patronato o direttamente dal sito Inps, per avere la concessione dei permessi ed altre agevolazioni, (fra cui anche il congedo straordinario di 2 anni), attraverso la sezione servizi telematici “Invio OnLine di Domande di Prestazioni a Sostegno del Reddito”, accessibile, da ogni contribuente mediante PIN o codice SPID personale. La domanda ha validità dal momento della sua presentazione, e non deve essere rinnovata annualmente anche se il datore di lavoro del familiare disabile ha facoltà di chiederne conferma all’inizio di ogni nuovo anno solare direttamente al lavoratore.

A chi spettano i permessi retribuiti

Ai sensi dell’art.33 della L.104/92, tali permessi vengono riconosciuti:

- Ai soggetti disabili in situazione di gravità
- Ai genitori, anche adottivi o affidatari, della persona disabile grave
- Al coniuge della stessa persona
- Ai parenti o affini entro il 2° grado, sempre in riferimento al disabile in situazione di gravità

escludendo da tale diritto i lavoratori a domicilio, gli addetti ai servizi domestici, gli agricoli a tempo determinato occupati a giornata, gli autonomi e i parasubordinati. Il beneficio può essere invece esteso anche a parenti ed affini di terzo grado, nel qual caso, però, i genitori o il coniuge del disabile grave devono aver compiuto 65 anni di età, oppure essere affetti da patologie invalidanti, o ancora deceduti o comunque mancanti. Il permesso viene a interrompersi nel momento i cui la persona disabile debba ricoverarsi a tempo pieno presso strutture ospedaliere o simili, pubbliche o private.

## Diritti riconosciuti per l’assistenza ai familiari disabili

I lavoratori disabili in situazione di gravità e i familiari, come elencato, che li assistono, possono usufruire, alternativamente, di:

- Riposi giornalieri, di 1 o 2 ore, in base all’orario di lavoro (1 ora se inferiore alle 6 quotidiane, 2 ore se superiore), senza che tale assenza vada a inficiare la buona riuscita dell’occupazione
- Tre giorni di permesso al mese, da comunicare al datore di lavoro in tempo utile

In più, i genitori, anche adottivi o affidatari, di figli disabili in situazione di gravità con età inferiore ai 3 anni, possono anche usufruire, in maniera comunque alternativa, anche del prolungamento del congedo parentale mentre, per le mamme e i papà di figli disabili dai 3 ai 12 anni viene escluso il riposo orario giornaliero, mantenendo però vigente sia il permesso dei 3 giorni che l’ulteriore congedo parentale.

I permessi sono indennizzati in base alla retribuzione effettivamente corrisposta: la Corte di Cassazione ha recentemente confermato che il loro utilizzo non può comportare un aggravio per il lavoratore, stabilendo anche che sono computabili sia per la maturazione delle ferie, sia per il calcolo della quattordicesima che per il cumulo contributivo.

Infine, si precisa che generalmente il permesso può essere utilizzato per l’assistenza di un solo familiare disabile ma, eccezionalmente, può essere possibile cumulare i relativi permessi, a queste condizioni:

- Per coniuge o parente/affine entro il 1° grado o il 2° nel caso in cui i genitori o il coniuge del disabile abbiano compiuto 65 anni di età, o anch’essi affetti da patologie invalidanti, piuttosto che deceduti o mancanti

La presenza del familiare sia disgiuntamente essenziale per ciascun disabile, escludendo pertanto la possibilità di cumulo quando sia possibile sopperire congiuntamente alla necessità nello stesso periodo.

### Altri Articoli Interessanti

- A Ugento (LE) Servizio Gratuito di Assistenza ai Disabili nelle Spiagge Libere del Salento
- Ad Ancona minori spese per l’assistenza domiciliare ai disabili
- ASL Tagli per l’Assistenza Domiciliare
- Fatti Adottare da un Disabile
- Sclerosi multipla e lo sport: gli esempi da seguire

## Un pensiero su “Permessi per l’assistenza ai familiari disabili”

1. Buonasera,
   sono una signora di 45 anni, invalida al 100% con inabilità lavorativa al 100% ( da quasi sempre), e ho la 104 art 3 comma 3. Mio marito ha 36 anni di contributi versati, purtroppo io da circa 2 anni necessito di assistenza continuativa per possibili cadute a terra alterazioni del contratto tale da rendermi inabile nelle comuni attività quotidiane, perciò ho da poco fatto la visita per l’accompagnamento. Volevo chiederle gentilmente, dato che mio marito ha solo 36 anni di contributi versati fra quanto potrebbe andare in pensione con la legge 104 art 3 comma 3 ? Spero vivamente in una Sua risposta.
   Grazie di Cuore, Nicoletta.

### Lascia un commento Annulla risposta

Il tuo indirizzo email non sarà pubblicato.

Commento

Nome

Email

Salva il mio nome, email e sito web in questo browser per la prossima volta che commento.

Δ

### Cerca

Cerca:

### Categorie

- Associazioni
- Eventi e Convegni
- Famiglia
- Formazione
- Lavoro
- Libri
- Malattie Rare
- Progetti
- Psicologia
- Salute
- Segnalazioni
- Societa
- Sport
- Storie di disabili
- Tecnologie
- Trasporti
- Vacanze

##### La tua privacy è importante per noi

Utilizziamo, senza il tuo consenso, cookies necessari alla elaborazione di analisi statistiche e tecnici per l'utilizzo del sito. Chiudendo il Cookie Banner, mediante il bottone RIFIUTA, continuerai a navigare in assenza di cookie di profilazione/marketing. Cliccando su ACCETTA acconsenti all'uso dei cookies di profilazione/marketing e potremo offrirti una navigazione migliore e messaggi pubblicitari corrispondenti alle tue esigenze. Policy Completa
ACCETTA RIFIUTA PERSONALIZZA
Impostazione dei tuoi Cookie

#### Panoramica Privacy

In relazione ai cookie che vengono installati sulla Sua macchina, informiamo che il conferimento dei dati è facoltativo. Tuttavia alcuni cookie sono necessari per consentire una corretta navigazione nel sito internet e pertanto, in assenza di consens...
Necessari
Necessari
Sempre abilitato
I cookie necessari sono assolutamente essenziali per il corretto funzionamento del sito web. Questi cookie garantiscono le funzionalità di base e le caratteristiche di sicurezza del sito web, in modo anonimo.

Cookie | Durata | Descrizione
--- | --- | ---
cookielawinfo-checkbox-advertisement | 1 year | Impostato dal plugin GDPR Cookie Consent; questo cookie viene utilizzato per registrare il consenso dell'utente per i cookie nella categoria "Pubblicità".
cookielawinfo-checkbox-analytics | 11 months | This cookie is set by GDPR Cookie Consent plugin. The cookie is used to store the user consent for the cookies in the category "Analytics".
cookielawinfo-checkbox-analytics | 11 months | Questo cookie è impostato dal plug-in GDPR Cookie Consent. Il cookie viene utilizzato per memorizzare il consenso dell'utente per i cookie nella categoria "Analytics".
cookielawinfo-checkbox-functional | 11 months | The cookie is set by GDPR cookie consent to record the user consent for the cookies in the category "Functional".
cookielawinfo-checkbox-functional | 11 months | Il cookie è impostato dal consenso cookie GDPR per registrare il consenso dell'utente per i cookie nella categoria "Funzionali".
cookielawinfo-checkbox-necessary | 11 months | This cookie is set by GDPR Cookie Consent plugin. The cookies is used to store the user consent for the cookies in the category "Necessary".
cookielawinfo-checkbox-necessary | 11 months | Questo cookie è impostato dal plug-in GDPR Cookie Consent. I cookie vengono utilizzati per memorizzare il consenso dell'utente per i cookie nella categoria "Necessari".
cookielawinfo-checkbox-others | 11 months | Questo cookie è impostato dal plug-in GDPR Cookie Consent. Il cookie viene utilizzato per memorizzare il consenso dell'utente per i cookie nella categoria "Altri".
cookielawinfo-checkbox-performance | 11 months | This cookie is set by GDPR Cookie Consent plugin. The cookie is used to store the user consent for the cookies in the category "Performance".
cookielawinfo-checkbox-performance | 11 months | Il cookie è impostato dal consenso cookie GDPR per registrare il consenso dell'utente per i cookie nella categoria "Performance".
PHPSESSID | session | Questo cookie è nativo delle applicazioni PHP. Il cookie viene utilizzato per memorizzare e identificare l'ID di sessione univoco dell'utente allo scopo di gestire la sessione dell'utente sul sito web. Il cookie è un cookie di sessione e viene cancellato alla chiusura di tutte le finestre del browser.
viewed_cookie_policy | 11 months | The cookie is set by the GDPR Cookie Consent plugin and is used to store whether or not user has consented to the use of cookies. It does not store any personal data.
viewed_cookie_policy | 11 months | Il cookie è impostato dal plug-in GDPR Cookie Consent e viene utilizzato per memorizzare se l'utente ha acconsentito o meno all'uso dei cookie. Non memorizza alcun dato personale.

Funzionali
functional
I cookie funzionali aiutano a eseguire determinate funzionalità come condividere il contenuto del sito Web su piattaforme di social media, raccogliere feedback e altre funzionalità di terze parti.
Prestazioni
performance
I cookie di performance vengono utilizzati per comprendere e analizzare gli indici di prestazioni chiave del sito Web che aiutano a fornire una migliore esperienza utente per i visitatori.
Analisi
analytics
I cookie analitici vengono utilizzati per capire come i visitatori interagiscono con il sito web. Questi cookie aiutano a fornire informazioni sulle metriche del numero di visitatori, frequenza di rimbalzo, fonte di traffico, ecc.

Cookie | Durata | Descrizione
--- | --- | ---
CONSENT | 2 years | YouTube imposta questo cookie tramite video youtube incorporati e registra dati statistici anonimi.

Pubblicitari
advertisement
I cookie pubblicitari vengono utilizzati per fornire ai visitatori annunci e campagne di marketing pertinenti. Questi cookie tengono traccia dei visitatori sui siti Web e raccolgono informazioni per fornire annunci personalizzati.

Cookie | Durata | Descrizione
--- | --- | ---
GoogleAdServingTest | session | Questo cookie viene utilizzato per determinare quali annunci sono stati mostrati al visitatore del sito web.
IDE | 1 year 24 days | I cookie di Google DoubleClick IDE vengono utilizzati per memorizzare informazioni su come l'utente utilizza il sito Web per presentargli annunci pertinenti e in base al profilo dell'utente.
test_cookie | 15 minutes | Il test_cookie è impostato da doubleclick.net e viene utilizzato per determinare se il browser dell'utente supporta i cookie.
VISITOR_INFO1_LIVE | 5 months 27 days | Un cookie impostato da YouTube per misurare la larghezza di banda che determina se l'utente ottiene la nuova o la vecchia interfaccia del lettore.
YSC | session | Il cookie YSC è impostato da Youtube e viene utilizzato per tenere traccia delle visualizzazioni dei video incorporati nelle pagine di Youtube.
yt-remote-connected-devices | never | YouTube imposta questo cookie per memorizzare le preferenze video dell'utente utilizzando il video YouTube incorporato.
yt-remote-device-id | never | YouTube imposta questo cookie per memorizzare le preferenze video dell'utente utilizzando il video YouTube incorporato.
__gads | 1 year 24 days | Il cookie __gads, impostato da Google, è memorizzato sotto il dominio DoubleClick e tiene traccia del numero di volte in cui gli utenti vedono un annuncio, misura il successo della campagna e ne calcola le entrate. Questo cookie può essere letto solo dal dominio su cui sono impostati e non terrà traccia di alcun dato durante la navigazione in altri siti.

Altri
others
Altri cookie non classificati sono quelli che vengono analizzati e non sono stati ancora classificati in una categoria.